@@ -8,7 +8,7 @@
 #######################################################################
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-Version = '0.3-1'
+Version = '0.4-1'
 
 import os
 import sys
@@ -58,6 +58,25 @@ def showQuickMessage(message):
                /org/freedesktop/Notifications \
                org.freedesktop.Notifications.SystemNoteInfoprint \
                string:"%s"' % message)          
+
+###########################################################
+
+''' Check for configulation files. '''               
+if CheckFile(PathTheme,ConfigTheme) == True:
+     Path = PathTheme
+     Config = ConfigTheme
+     message = 'INFO: Reading the CURRENT configuration from the theme folder..'
+elif CheckFile(PathSystem,ConfigSystem) == True:
+     Path = PathSystem
+     Config = ConfigSystem
+     message = 'INFO: Reading the CURRENT configuration from the system folder..'
+else:
+     message = 'WARNING: Unable to find any configuration file. Exiting..'
+     sys.exit(1)
+
+showMessage(message)
+
+############################################################
                
 def doUpdateConfigSystem():            
     ''' Update the config file of the system with the edited. '''
@@ -222,7 +241,7 @@ class MyMainWindow(QtGui.QMainWindow):
              # message = 'The CURRENT configuration options are shown.'
              # showQuickMessage(message)
 
-        def doSetDefault(self): ##FIXME: implement method!!!    
+        def doSetDefault(self):  
              ''' Set DEFAULT values in the GUI''' 
 
              self.ui.comboBoxBlurless.setCurrentIndex(0)
@@ -331,6 +350,8 @@ if __name__ == "__main__":
         os.system('cp %s %s' % (PathTheme + ConfigTheme, PathTemp + ConfigTempTheme))
         message = 'INFO: The application found a settings file in the theme folder.\nThe application will update both system and theme files with any changes requested.'
         showMessage(message)
+    else:
+        pass
         
     ##Open Dialog Window
     app = QtGui.QApplication(sys.argv)
